/*
 * $Header: /home/jerenkrantz/tmp/commons/commons-convert/cvs/home/cvs/jakarta-commons//resources/src/test/org/apache/commons/resources/MessagesTestCase.java,v 1.9 2004/03/27 21:34:10 dgraham Exp $
 * $Revision: 1.9 $
 * $Date: 2004-03-27 16:34:10 -0500 (Sat, 27 Mar 2004) $
 *
 * ====================================================================
 *
 *  Copyright 2003-2004 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.apache.commons.resources.impl.ResourceBundleResourcesFactory;

/**
 * <p>Unit tests for
 * <code>org.apache.commons.resources.Messages</code>.
 * </p>
 */
public class MessagesTestCase extends TestCase {

    // Configuration value for our resource bundles
    protected static final String CONFIG = "org.apache.commons.resources.impl.TestResources";

    // Logical name of the Resources instance to be created
    protected static final String NAME = "name";


    // The ResourcesFactory to use for acquiring the Resources
    protected ResourcesFactory factory = null;


    // The Resources instance containing our messages
    protected Resources resources = null;

    // The Messages instance to be tested
    protected Messages messages = null;


    // ----------------------------------------------------------- Constructors


    public MessagesTestCase(String name) {
        super(name);
    }


    // --------------------------------------------------- Overall Test Methods


    // Set up instance variables required by this test case
    public void setUp() throws Exception {
        factory = new ResourceBundleResourcesFactory();
        resources = factory.getResources(NAME, CONFIG);
        messages = new Messages(resources);
    }

    // Return the tests included in this test suite
    public static Test suite() {
        return (new TestSuite(MessagesTestCase.class));
    }

    // Tear down the instance variables required by this test case
    public void tearDown() {
        messages = null;
        resources = null;
        factory = null;
    }


    // ------------------------------------------------ Individual Test Methods


    /**
     * Test the use of the shortcut getMessages() method.
     */
	public void testLocal() {
		String message = null;
        
		Messages local =
			Messages.getMessages(
				"org.apache.commons.resources.impl.LocalStrings");
		
        assertNotNull("Local messages found", local);

		message = local.getMessage("local.message");
		
        assertEquals(
			"Correct individual message",
			"[Local] REPLACE {0} WITH {1}",
			message);

		message =
			local.getMessage("local.message", new String[] { "abc", "def" });
            
		assertEquals(
			"Correct replaced message",
			"[Local] REPLACE abc WITH def",
			message);

		message = local.getMessage("local.missing");
		assertEquals("Correct missing message", "???local.missing???", message);
	}


    /**
     * Test the ability to retrieve messages with replacements.
     */
	public void testMessages() {
		String message = null;

		message = messages.getMessage("test.message");
		assertEquals(
			"Correct individual message",
			"[Base] REPLACE {0} WITH {1}",
			message);

		message =
			messages.getMessage("test.message", new String[] { "abc", "def" });
		
        assertEquals(
			"Correct replaced message",
			"[Base] REPLACE abc WITH def",
			message);

		message = messages.getMessage("test.missing");
		assertEquals("Correct missing message", "???test.missing???", message);
	}


    /**
     * Test the characteristics of a newly created instance.
     */
	public void testPristine() {
		assertNotNull(messages);
		assertTrue(
			"Correct wrapped resources",
			resources == messages.getResources());
	}


}
