/*
 * $Header: /home/jerenkrantz/tmp/commons/commons-convert/cvs/home/cvs/jakarta-commons//resources/src/test/org/apache/commons/resources/impl/ResourcesBaseTestCase.java,v 1.12 2004/09/07 23:49:47 jmitchell Exp $
 * $Revision: 1.12 $
 * $Date: 2004-09-07 19:49:47 -0400 (Tue, 07 Sep 2004) $
 *
 * ====================================================================
 *
 *  Copyright 2003-2004 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.impl;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.commons.resources.Resources;
import org.apache.commons.resources.ResourcesException;
import org.apache.commons.resources.ResourcesKeyException;

/**
 * <p>Unit tests for
 * <code>org.apache.commons.resources.impl.ResourcesBase</code>.
 * </p>
 */
public class ResourcesBaseTestCase extends ResourcesFactoryBaseTestCase {


    // ----------------------------------------------------- Instance Variables


    // The Resources instance to be tested
    protected Resources resources = null;


    // ----------------------------------------------------------- Constructors


    public ResourcesBaseTestCase(String name) {
        super(name);
    }


    // --------------------------------------------------- Overall Test Methods


    // Set up instance variables required by this test case
    public void setUp() throws Exception {
        super.setUp();
        resources = factory.getResources(NAME);
    }

    // Return the tests included in this test suite
    public static Test suite() {
        return (new TestSuite(ResourcesBaseTestCase.class));
    }

    // Tear down the instance variables required by this test case
    public void tearDown() {
        resources = null;
        super.tearDown();
    }


    // ------------------------------------------------ Individual Test Methods


    // Test retrieving Strings that should be inherited from parent Locales
    public void testInherit() throws Exception {

        Locale locale = null;

        locale = new Locale("en", "US");
        assertEquals("en_US inherit value",
                     "[test] INHERIT",
                     resources.getString("test.inherit", locale, null));

        locale = new Locale("fr", "FR");
        assertEquals("fr_FR inherit value",
                     "[test] INHERIT",
                     resources.getString("test.inherit", locale, null));

    }


    // Test retrieving all of the defined keys
    public void testKeys() throws Exception {

        // Pre-seed all of the keys we expect to find
        Locale locale = new Locale("en", "US");
        resources.getString("test.base", locale, null);
        resources.getString("test.specific", locale, null);
        resources.getString("test.inherit", locale, null);
        resources.getString("test.message", locale, null);

        // Accumulate all of the keys that are actually returned
        List results = new ArrayList();
        Iterator keys = resources.getKeys();
        while (keys.hasNext()) {
            results.add(keys.next());
        }

        // Validate the keys that were actually returned
        assertEquals(4, results.size());
        assertTrue(results.contains("test.base"));
        assertTrue(results.contains("test.specific"));
        assertTrue(results.contains("test.inherit"));
        assertTrue(results.contains("test.message"));

    }


    // Test retrieving missing resource keys
    public void testMissing() throws Exception {

        Locale locale = new Locale("en","");
        try {
            resources.setReturnNull(false);
            resources.getString("test.missing", locale, null);
            fail("Should have thrown ResourcesException");
        } catch (ResourcesKeyException e) {
            // Expected result
        }
        try {
            resources.setReturnNull(true);
            String value = resources.getString("test.missing", locale, null);
            assertTrue("Should have returned null", value == null);
        } catch (ResourcesException e) {
            fail("Should have returned null");
        }

    }


    // Test the characteristics of a newly created instance
    public void testPristine() {
        assertNotNull(resources);
        assertEquals("Correct name", NAME, resources.getName());
        if (resources instanceof TestResources) {
            assertTrue("Resources initialized",
                       ((TestResources) resources).isInitialized());
        }
    }


    // Test that releasing should destroy instances
    public void testRelease() throws Exception {
        factory.release();
        if (resources instanceof TestResources) {
            assertTrue("Resources destroyed",
                       !((TestResources) resources).isInitialized());
        }
    }


    // Test retrieving Locale-specific Strings explicitly
    public void testSpecific() throws Exception {

        Locale locale = null;

        locale = new Locale("en","");
        assertEquals("en specific value",
                     "[test] SPECIFIC",
                     resources.getString("test.specific", locale, null));

        locale = new Locale("en", "US");
        assertEquals("en_US specific value",
                     "[test] SPECIFIC",
                     resources.getString("test.specific", locale, null));

        locale = new Locale("fr","");
        assertEquals("fr specific value",
                     "[test] SPECIFIC",
                     resources.getString("test.specific", locale, null));

    }


}
