/*
 * $Header: /home/jerenkrantz/tmp/commons/commons-convert/cvs/home/cvs/jakarta-commons//resources/src/test/org/apache/commons/resources/impl/TestResources.java,v 1.11 2004/09/07 23:49:47 jmitchell Exp $
 * $Revision: 1.11 $
 * $Date: 2004-09-07 19:49:47 -0400 (Tue, 07 Sep 2004) $
 *
 * ====================================================================
 *
 *  Copyright 2003-2004 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.TimeZone;

import org.apache.commons.resources.ResourcesException;
import org.apache.commons.resources.ResourcesKeyException;

/**
 * <p>Concrete implementation of {@link org.apache.commons.resources.Resources} 
 * for unit tests.</p>
 */
public class TestResources extends ResourcesBase {


    // ----------------------------------------------------------- Constructors


    // Construct a test instance with the specified name
    public TestResources(String name) {
        super(name);
    }


    // ----------------------------------------------------- Instance Variables


    // Has this instance been initialized?
    protected boolean initialized = false;


    // Map of resource String values
    protected Map map = new HashMap();


    // ------------------------------------------------------ Lifecycle Methods


    // Initialize this Resources instance
    public void init() throws ResourcesException {

        super.init();
        map.put("test.specific", "[test] SPECIFIC");
        map.put("test.inherit", "[test] INHERIT");
        initialized = true;

    }


    // Destroy this Resources instance
    public void destroy() throws ResourcesException {

        super.destroy();
        map.clear();
        initialized = false;

    }


    // ------------------------------------------------------------- Properties


    // Return the keys for all defined Resources
    public Iterator getKeys() {

        List results = new ArrayList();
        results.add("test.base");
        results.add("test.specific");
        results.add("test.inherit");
        results.add("test.message");
        return (results.iterator());

    }


    // Has this instance been initialized?
    public boolean isInitialized() {
        return (this.initialized);
    }


    // ---------------------------------------------- Content Retrieval Methods


    /**
     * <p>Return the content for the specified <code>key</code> as an
     * Object, localized based on the specified <code>locale</code>
     * and/or <code>timeZone</code>.</p>
     *
     * @param key Identifier for the requested content
     * @param locale Locale with which to localize retrieval,
     *  or <code>null</code> for the default Locale
     * @param timeZone TimeZone with which to localize retrieval,
     *  or <code>null</code> for the default TimeZone
     *
     * @exception ResourcesException if an error occurs retrieving or
     *  returning the requested content
     * 
     * @TODO - FIXME - why is locale and timeZone ignored here?
     */
    public Object getObject(String key){
        return getObject(key, null, null);
    }
    public Object getObject(String key, Locale locale, TimeZone timeZone)
        throws ResourcesException {

        Object value = map.get(key);
        if (value == null) {
            if (isReturnNull()) {
                return (null);
            } else {
                throw new ResourcesKeyException(key);
            }
        }
        return (value);

    }


}
